@@ -8,6 +8,10 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ktechlab.h"
 
 #include <dcopclient.h>
@@ -57,8 +61,12 @@ int main(int argc, char **argv)
 	return app.exec();
 }
 
-void exit_gpsim(int ret)
+#ifndef NO_GPSIM
+
+KDE_EXPORT void exit_gpsim(int ret)
 {
 	printf("gpsim attempted to call exit_gpsim(%d), ***IGNORING***\n", ret);
 //	exit(ret);
 }
+
+#endif
