@@ -14,8 +14,8 @@
 #include <itemview.h>
 
 class ICNDocument;
-class KRadioAction;
-class KToolBarPopupAction;
+class TDERadioAction;
+class TDEToolBarPopupAction;
 
 /**
 @author David Saxton
@@ -23,7 +23,7 @@ class KToolBarPopupAction;
 class ICNView : public ItemView
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
 		ICNView( ICNDocument * icnDocument, ViewContainer *viewContainer, uint viewAreaId, const char * name = 0l );
 		~ICNView();
@@ -36,9 +36,9 @@ class ICNView : public ItemView
 		void slotUpdateRoutingToggles( bool manualRouting );
 		
 	protected:
-		KToolBarPopupAction * m_pRoutingModeToolbarPopup;
-		KRadioAction * m_pManualRoutingAction;
-		KRadioAction * m_pAutoRoutingAction;
+		TDEToolBarPopupAction * m_pRoutingModeToolbarPopup;
+		TDERadioAction * m_pManualRoutingAction;
+		TDERadioAction * m_pAutoRoutingAction;
 };
 
 #endif
